@@ -6,7 +6,7 @@ from sqlalchemy.ext.serializer import loads, dumps
 from widgets import ChartWidget
 from ..widgets import SearchWidget
 from ..security.decorators import has_access
-from ..views import BaseModelView, expose
+from ..baseviews import BaseModelView, expose
 from ..forms import GeneralModelConverter
 from ..urltools import *
 
@@ -43,7 +43,7 @@ class BaseChartView(BaseModelView):
         super(BaseChartView, self).__init__(**kwargs)
     
 
-    def _get_chart_widget(self, value_columns = [], widgets = {}):        
+    def _get_chart_widget(self, value_columns = [], widgets = {}):
         widgets['chart'] = self.chart_widget(route_base = self.route_base,
                                              chart_title = self.chart_title, 
                                              chart_type = self.chart_type,
